==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/hr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Navedeni operater nije važeći",
    "The given regular expression is invalid" : "Navedeni regularni izraz nije važeći",
    "The given file size is invalid" : "Navedena veličina datoteke nije važeća",
    "The given tag id is invalid" : "Navedeni ID oznake nije važeći",
    "The given IP range is invalid" : "Navedeni raspon IP adresa nije važeći",
    "The given IP range is not valid for IPv4" : "Navedeni raspon IP adresa ne vrijedi za IPv4",
    "The given IP range is not valid for IPv6" : "Navedeni raspon IP adresa ne vrijedi za IPv6",
    "The given time span is invalid" : "Navedeno vremensko razdoblje nije važeće",
    "The given start time is invalid" : "Navedeno vrijeme početka nije važeće",
    "The given end time is invalid" : "Navedeno vrijeme završetka nije važeće",
    "The given group does not exist" : "Navedena grupa ne postoji",
    "File" : "Datoteka",
    "File created" : "Datoteka je stvorena",
    "File updated" : "Datoteka je ažurirana",
    "File renamed" : "Datoteka je preimenovana",
    "File deleted" : "Datoteka je izbrisana",
    "File accessed" : "Datoteci je pristupljeno",
    "File copied" : "Datoteka je kopirana",
    "Tag assigned" : "Dodijeljena oznaka",
    "Someone" : "Netko",
    "%s created %s" : "%s je stvorio %s",
    "%s modified %s" : "%s je izmijenio %s",
    "%s deleted %s" : "%s je izbrisao %s",
    "%s accessed %s" : "%s je pristupio %s",
    "%s renamed %s" : "%s je preimenovao %s",
    "%s copied %s" : "%s je kopirao %s",
    "%s assigned %s to %s" : "%s je dodijelio %s %s",
    "Operation #%s does not exist" : "Radnja #%s ne postoji",
    "Entity %s does not exist" : "Entitet %s ne postoji",
    "Entity %s is invalid" : "Entitet %s nije valjan",
    "No events are chosen." : "Nema odabranih događaja.",
    "Entity %s has no event %s" : "Entitet %s nema događaja %s",
    "Operation %s does not exist" : "Radnja %s ne postoji",
    "Operation %s is invalid" : "Radnja %s nije važeća",
    "At least one check needs to be provided" : "Morate odabrati barem jednu od ponuđenih mogućnosti",
    "The provided operation data is too long" : "Pruženi podaci o radnji su predugački",
    "Invalid check provided" : "Odabrana je nevažeća mogućnost",
    "Check %s does not exist" : "Provjera %s ne postoji",
    "Check %s is invalid" : "Provjera %s nije važeća",
    "Check %s is not allowed with this entity" : "Provjera %s nije dopuštena s ovim entitetom",
    "The provided check value is too long" : "Pružena vrijednost provjere je predugačka",
    "Check #%s does not exist" : "Provjera #%s ne postoji",
    "Check %s is invalid or does not exist" : "Provjera %s nije važeća ili ne postoji",
    "Flow" : "Tijek",
    "Nextcloud workflow engine" : "Upravljački program tijeka rada Nextclouda",
    "Select a filter" : "Odaberi filtar",
    "Select a comparator" : "Odaberi usporednik",
    "Audio" : "Audio",
    "Folder" : "Mapa",
    "Images" : "Slike",
    "Office documents" : "Dokumenti paketa Office",
    "PDF documents" : "Dokumenti PDF",
    "Custom mimetype" : "Prilagođeni mimetype",
    "Select a file type" : "Odaberi vrstu datoteke",
    "e.g. httpd/unix-directory" : "npr. httpd/unix-directory",
    "Please enter a valid time span" : "Unesite valjani vremenski raspon",
    "Files WebDAV" : "Datoteke WebDAV",
    "Custom URL" : "Prilagođeni URL",
    "Select a request URL" : "Odaberi URL zahtjeva",
    "Android client" : "Klijent za Android",
    "iOS client" : "Klijent za iOS",
    "Desktop client" : "Klijent za stolna računala",
    "Thunderbird & Outlook addons" : "Dodaci za Thunderbird i Outlook",
    "Custom user agent" : "Prilagođeni korisnički agent",
    "Select a user agent" : "Odaberi korisničkog agenta",
    "Select groups" : "Označi grupe",
    "Groups" : "Grupe",
    "At least one event must be selected" : "Morate odabrati barem jedan događaj",
    "Add new flow" : "Dodaj novi tijek",
    "The configuration is invalid" : "Konfiguracija nije valjana",
    "Active" : "Aktivan",
    "Save" : "Spremi",
    "When" : "Kada",
    "and" : "i",
    "Cancel" : "Odustani",
    "Delete" : "Izbriši",
    "Available flows" : "Dostupni tijekovi",
    "For details on how to write your own flow, check out the development documentation." : "Više informacija o pisanju vlastitog tijeka možete pronaći u razvojnoj dokumentaciji.",
    "More flows" : "Više tijekova",
    "Browse the App Store" : "Pretraži trgovinu aplikacijama",
    "Show less" : "Prikaži manje",
    "Show more" : "Prikaži više",
    "Configured flows" : "Konfigurirani tijekovi",
    "Your flows" : "Vaši tijekovi",
    "matches" : "podudara se",
    "does not match" : "ne podudara se",
    "is" : "je",
    "is not" : "nije",
    "File name" : "Naziv datoteke",
    "File MIME type" : "Vrsta MIME datoteke",
    "File size (upload)" : "Veličina datoteke (otprema)",
    "less" : "manje",
    "less or equals" : "manje ili jednako",
    "greater or equals" : "veće ili jednako",
    "greater" : "veće",
    "Request remote address" : "Zatraži udaljenu adresu",
    "matches IPv4" : "odgovara IPv4",
    "does not match IPv4" : "ne odgovara IPv4",
    "matches IPv6" : "odgovara IPv6",
    "does not match IPv6" : "ne odgovara IPv6",
    "File system tag" : "Oznaka datotečnog sustava",
    "is tagged with" : "označeno je sa",
    "is not tagged with" : "nije označeno sa",
    "Request URL" : "Zatraži URL",
    "Request time" : "Zatraži vrijeme",
    "between" : "između",
    "not between" : "nije između",
    "Request user agent" : "Zatraži korisničkog agenta",
    "is member of" : "je član",
    "is not member of" : "nije član"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/hr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Navedeni operater nije važeći",
    "The given regular expression is invalid" : "Navedeni regularni izraz nije važeći",
    "The given file size is invalid" : "Navedena veličina datoteke nije važeća",
    "The given tag id is invalid" : "Navedeni ID oznake nije važeći",
    "The given IP range is invalid" : "Navedeni raspon IP adresa nije važeći",
    "The given IP range is not valid for IPv4" : "Navedeni raspon IP adresa ne vrijedi za IPv4",
    "The given IP range is not valid for IPv6" : "Navedeni raspon IP adresa ne vrijedi za IPv6",
    "The given time span is invalid" : "Navedeno vremensko razdoblje nije važeće",
    "The given start time is invalid" : "Navedeno vrijeme početka nije važeće",
    "The given end time is invalid" : "Navedeno vrijeme završetka nije važeće",
    "The given group does not exist" : "Navedena grupa ne postoji",
    "File" : "Datoteka",
    "File created" : "Datoteka je stvorena",
    "File updated" : "Datoteka je ažurirana",
    "File renamed" : "Datoteka je preimenovana",
    "File deleted" : "Datoteka je izbrisana",
    "File accessed" : "Datoteci je pristupljeno",
    "File copied" : "Datoteka je kopirana",
    "Tag assigned" : "Dodijeljena oznaka",
    "Someone" : "Netko",
    "%s created %s" : "%s je stvorio %s",
    "%s modified %s" : "%s je izmijenio %s",
    "%s deleted %s" : "%s je izbrisao %s",
    "%s accessed %s" : "%s je pristupio %s",
    "%s renamed %s" : "%s je preimenovao %s",
    "%s copied %s" : "%s je kopirao %s",
    "%1$s assigned %2$s to %3$s" : "%1$s je dodijelio/la %2$s korisniku %3$s",
    "Operation #%s does not exist" : "Radnja #%s ne postoji",
    "Entity %s is invalid" : "Entitet %s nije valjan",
    "Entity %s does not exist" : "Entitet %s ne postoji",
    "No events are chosen." : "Nema odabranih događaja.",
    "Entity %s has no event %s" : "Entitet %s nema događaja %s",
    "The provided operation data is too long" : "Pruženi podaci o radnji su predugački",
    "Operation %s is invalid" : "Radnja %s nije važeća",
    "Operation %s does not exist" : "Radnja %s ne postoji",
    "At least one check needs to be provided" : "Morate odabrati barem jednu od ponuđenih mogućnosti",
    "Invalid check provided" : "Odabrana je nevažeća mogućnost",
    "The provided check value is too long" : "Pružena vrijednost provjere je predugačka",
    "Check %s is invalid" : "Provjera %s nije važeća",
    "Check %s does not exist" : "Provjera %s ne postoji",
    "Check %s is not allowed with this entity" : "Provjera %s nije dopuštena s ovim entitetom",
    "Check #%s does not exist" : "Provjera #%s ne postoji",
    "Check %s is invalid or does not exist" : "Provjera %s nije važeća ili ne postoji",
    "Flow" : "Tijek",
    "Nextcloud workflow engine" : "Upravljački program tijeka rada Nextclouda",
    "Select a filter" : "Odaberi filtar",
    "Select a comparator" : "Odaberi usporednik",
    "Remove filter" : "Ukloni filter",
    "Audio" : "Audio",
    "Folder" : "Mapa",
    "Images" : "Slike",
    "Office documents" : "Dokumenti paketa Office",
    "PDF documents" : "Dokumenti PDF",
    "Video" : "Videozapis",
    "Custom MIME type" : "Prilagođena MIME vrsta",
    "Select a file type" : "Odaberi vrstu datoteke",
    "e.g. httpd/unix-directory" : "npr. httpd/unix-directory",
    "Please enter a valid time span" : "Unesite valjani vremenski raspon",
    "Files WebDAV" : "Datoteke WebDAV",
    "Custom URL" : "Prilagođeni URL",
    "Select a request URL" : "Odaberi URL zahtjeva",
    "Android client" : "Klijent za Android",
    "iOS client" : "Klijent za iOS",
    "Desktop client" : "Klijent za stolna računala",
    "Thunderbird & Outlook addons" : "Dodaci za Thunderbird i Outlook",
    "Custom user agent" : "Prilagođeni korisnički agent",
    "Select a user agent" : "Odaberi korisničkog agenta",
    "Select groups" : "Označi grupe",
    "Groups" : "Grupe",
    "Type to search for group …" : "Upišite za pretraživanje grupe …",
    "Select a trigger" : "Odaberite okidač",
    "At least one event must be selected" : "Morate odabrati barem jedan događaj",
    "Add new flow" : "Dodaj novi tijek",
    "The configuration is invalid" : "Konfiguracija nije valjana",
    "Active" : "Aktivan",
    "Save" : "Spremi",
    "When" : "Kada",
    "and" : "i",
    "Add a new filter" : "Dodaj novi filter",
    "Cancel" : "Odustani",
    "Delete" : "Izbriši",
    "Available flows" : "Dostupni tijekovi",
    "For details on how to write your own flow, check out the development documentation." : "Više informacija o pisanju vlastitog tijeka možete pronaći u razvojnoj dokumentaciji.",
    "No flows installed" : "Tijekovi nisu instalirani",
    "Ask your administrator to install new flows." : "Zatražite od administratora instalaciju novih tijekova.",
    "More flows" : "Više tijekova",
    "Browse the App Store" : "Pretraži trgovinu aplikacijama",
    "Show less" : "Prikaži manje",
    "Show more" : "Prikaži više",
    "Configured flows" : "Konfigurirani tijekovi",
    "Your flows" : "Vaši tijekovi",
    "No flows configured" : "Nema konfiguriranih tijekova",
    "matches" : "podudara se",
    "does not match" : "ne podudara se",
    "is" : "je",
    "is not" : "nije",
    "File name" : "Naziv datoteke",
    "File MIME type" : "Vrsta MIME datoteke",
    "File size (upload)" : "Veličina datoteke (otprema)",
    "less" : "manje",
    "less or equals" : "manje ili jednako",
    "greater or equals" : "veće ili jednako",
    "greater" : "veće",
    "Request remote address" : "Zatraži udaljenu adresu",
    "matches IPv4" : "odgovara IPv4",
    "does not match IPv4" : "ne odgovara IPv4",
    "matches IPv6" : "odgovara IPv6",
    "does not match IPv6" : "ne odgovara IPv6",
    "File system tag" : "Oznaka datotečnog sustava",
    "is tagged with" : "označeno je sa",
    "is not tagged with" : "nije označeno sa",
    "Request URL" : "Zatraži URL",
    "Request time" : "Zatraži vrijeme",
    "between" : "između",
    "not between" : "nije između",
    "Request user agent" : "Zatraži korisničkog agenta",
    "Group membership" : "Članstvo u grupi",
    "is member of" : "je član",
    "is not member of" : "nije član",
    "Type to search for group …" : "Upišite za pretraživanje grupe …"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
